<?php

namespace Bixo\CrossTrade\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\CrossTrade\Actions\OfferUsVehicleAction;
use Bixo\CrossTrade\Http\Requests\OfferUsVehicleActionRequest;
use Bixo\CrossTrade\Http\Resources\OfferUsVehicleResource;
use Bixo\CrossTrade\Models\OfferUsVehicle;

/**
 * Admin web controller class.
 */
class OfferUsVehicleActionController extends BaseController
{

    /**
     * Action controller function for offer_us_vehicle.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OfferUsVehicleActionRequest $request, OfferUsVehicle $offer_us_vehicle, $action)
    {
        try {
            $request = $request->all();
            $offer_us_vehicle = OfferUsVehicleAction::run($action, $offer_us_vehicle, $request);

            $data = new OfferUsVehicleResource($offer_us_vehicle);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('cross_trade::offer_us_vehicle.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('cross_trade/offer_us_vehicle/' . $offer_us_vehicle->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('cross_trade/offer_us_vehicle/' . $offer_us_vehicle->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
