<?php

namespace Bixo\CrossTrade\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\CrossTrade\Actions\OrderVehicleAction;
use Bixo\CrossTrade\Http\Requests\OrderVehicleActionRequest;
use Bixo\CrossTrade\Http\Resources\OrderVehicleResource;
use Bixo\CrossTrade\Models\OrderVehicle;

/**
 * Admin web controller class.
 */
class OrderVehicleActionController extends BaseController
{

    /**
     * Action controller function for order_vehicle.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OrderVehicleActionRequest $request, OrderVehicle $order_vehicle, $action)
    {
        try {
            $request = $request->all();
            $order_vehicle = OrderVehicleAction::run($action, $order_vehicle, $request);

            $data = new OrderVehicleResource($order_vehicle);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('cross_trade::order_vehicle.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('cross_trade/order_vehicle/' . $order_vehicle->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('cross_trade/order_vehicle/' . $order_vehicle->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
