<?php

namespace Bixo\CrossTrade\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\CrossTrade\Actions\OrderVehicleExim;
use Bixo\CrossTrade\Http\Requests\OrderVehicleEximRequest;

/**
 * Admin web controller class.
 */
class OrderVehicleEximController extends BaseController
{
    /**
     * Action controller function for order_vehicle.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OrderVehicleEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = OrderVehicleExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('cross_trade:order_vehicle.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('cross_trade/order_vehicle/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('cross_trade/order_vehicle/' . $exim))
                ->redirect();
        }
    }
}
