<?php

namespace Bixo\CrossTrade\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\CrossTrade\Http\Resources\CrossTradeResource;
use Bixo\CrossTrade\Http\Resources\CrossTradesCollection;
use Bixo\CrossTrade\Scopes\OrderVehiclePublicScope;
use Bixo\CrossTrade\Models\OrderVehicle;

class OrderVehiclePublicController extends BaseController
{

    /**
     * Show order_vehicle's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = OrderVehicle::pushScope(new RequestScope())
            ->pushScope(new OrderVehiclePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $order_vehicles = new OrderVehiclesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('cross_trade::order_vehicle.names'))
            ->view('cross_trade::public.order_vehicle.index')
            ->data(compact('order_vehicles', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show order_vehicle.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = OrderVehicle::findBySlug($slug);
        $data = new OrderVehicleResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('cross_trade::order_vehicle.name'))
            ->view('cross_trade::public.order_vehicle.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
