<?php

namespace Bixo\CrossTrade\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\CrossTrade\Events\OfferUsVehicleWorkflow as OfferUsVehicleWorkflowEvent;
use Bixo\CrossTrade\Notifications\OfferUsVehicleWorkflow as OfferUsVehicleWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class OfferUsVehicleWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(OfferUsVehicleWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $offer_us_vehicle is submitted.
     *
     * @param OfferUsVehicleWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(OfferUsVehicleWorkflowEvent $event)
    {
        $client = $event->offer_us_vehicle->client;
        Notification::send($client, new OfferUsVehicleWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $offer_us_vehicle is published.
     *
     * @param OfferUsVehicleWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(OfferUsVehicleWorkflowEvent $event)
    {
        $client = $event->offer_us_vehicle->client;
        Notification::send($client, new OfferUsVehicleWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $offer_us_vehicle is approved.
     *
     * @param OfferUsVehicleWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(OfferUsVehicleWorkflowEvent $event)
    {
        $client = $event->offer_us_vehicle->client;
        Notification::send($client, new OfferUsVehicleWorkflowNotification($event));
    }

    /**
     * Handles the $offer_us_vehicle workflow event as a listener.
     *
     * @param OfferUsVehicleWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(OfferUsVehicleWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
