<?php

namespace Bixo\CrossTrade\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\CrossTrade\Models\OfferUsVehicle;

class OfferUsVehiclePolicy
{

    use OfferUsVehicleAction;
    use OfferUsVehicleExim;
    use OfferUsVehicleReport;
    use OfferUsVehicleWorkflow;

    /**
     * Determine if the given user can view the offer_us_vehicle.
     *
     * @param Authenticatable $user
     * @param OfferUsVehicle $offer_us_vehicle
     *
     * @return bool
     */
    public function view(Authenticatable $user, OfferUsVehicle $offer_us_vehicle)
    {
        if ($authUser->canDo('cross_trade.offer_us_vehicle.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $offer_us_vehicle->is_owner;
    }

    /**
     * Determine if the given user can create a offer_us_vehicle.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('cross_trade.offer_us_vehicle.create');
    }

    /**
     * Determine if the given user can update the given offer_us_vehicle.
     *
     * @param Authenticatable $user
     * @param OfferUsVehicle $offer_us_vehicle
     *
     * @return bool
     */
    public function update(Authenticatable $user, OfferUsVehicle $offer_us_vehicle)
    {
        if ($user->canDo('cross_trade.offer_us_vehicle.edit') && $user->isAdmin()) {
            return true;
        }

        return $offer_us_vehicle->is_owner;
    }

    /**
     * Determine if the given user can delete the given offer_us_vehicle.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, OfferUsVehicle $offer_us_vehicle)
    {
        return $offer_us_vehicle->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
