<?php

namespace Bixo\CrossTrade\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\CrossTrade\Models\OrderVehicle;

class OrderVehiclePolicy
{

    use OrderVehicleAction;
    use OrderVehicleExim;
    use OrderVehicleReport;
    use OrderVehicleWorkflow;

    /**
     * Determine if the given user can view the order_vehicle.
     *
     * @param Authenticatable $user
     * @param OrderVehicle $order_vehicle
     *
     * @return bool
     */
    public function view(Authenticatable $user, OrderVehicle $order_vehicle)
    {
        if ($authUser->canDo('cross_trade.order_vehicle.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $order_vehicle->is_owner;
    }

    /**
     * Determine if the given user can create a order_vehicle.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('cross_trade.order_vehicle.create');
    }

    /**
     * Determine if the given user can update the given order_vehicle.
     *
     * @param Authenticatable $user
     * @param OrderVehicle $order_vehicle
     *
     * @return bool
     */
    public function update(Authenticatable $user, OrderVehicle $order_vehicle)
    {
        if ($user->canDo('cross_trade.order_vehicle.edit') && $user->isAdmin()) {
            return true;
        }

        return $order_vehicle->is_owner;
    }

    /**
     * Determine if the given user can delete the given order_vehicle.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, OrderVehicle $order_vehicle)
    {
        return $order_vehicle->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
