<?php

namespace Bixo\CrossTrade\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\CrossTrade\CrossTrades;

class CrossTradeServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'cross_trade');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'cross_trade');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Bixo\CrossTrade\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\CrossTrade\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\CrossTrade\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\CrossTrade\Providers\EventServiceProvider::class);
        $this->app->register(\Bixo\CrossTrade\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.cross_trade', function($app)
        {
            return $this->app->make(CrossTrade::class);
        });
    }

    /**
     * Merges user's and cross_trade's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.cross_trade'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/order_vehicle.php', 'bixo.cross_trade.order_vehicle'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/offer_us_vehicle.php', 'bixo.cross_trade.offer_us_vehicle'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.cross_trade'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/cross_trade')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/cross_trade')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/cross_trade')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
